<?php
/**
 * TP Philosophy Pro works section customizer options
 *
 * @package Theme_Palace
 * @subpackage TP_Philosophy_Pro
 * @since 1.0
 */

// Add works section
$wp_customize->add_section( 'tp_philosophy_pro_works_section', array(
	'title'             => esc_html__( 'Works', 'tp-philosophy-pro' ),
	'description'       => esc_html__( 'Works section options.', 'tp-philosophy-pro' ),
	'panel'             => 'tp_philosophy_pro_homepage_sections_panel'
) );

// Add works section enable setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_enable]', array(
	'default'           => $options['works_enable'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_enable]', array(
	'label'             => esc_html__( 'Enable on', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_works_section',
	'type'              => 'select',
	'choices'           => tp_philosophy_pro_enable_disable_options()
) );

// Add works section content type setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_content_type]', array(
	'default'           => $options['works_content_type'],
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_select'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_content_type]', array(
	'label'           	=> esc_html__( 'Content Type', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_works_section',
	'type'            	=> 'select',
	'active_callback' 	=> 'tp_philosophy_pro_is_works_enable',
	'choices'         	=> array(
		'demo'     => esc_html__( 'Demo', 'tp-philosophy-pro' ),
		'page'    => esc_html__( 'Pages', 'tp-philosophy-pro' ),
		'custom'   => esc_html__( 'Custom', 'tp-philosophy-pro' ),
    ),
) );

// Add setting and controls to input page id
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_page_id]', array(
	'sanitize_callback' => 'tp_philosophy_pro_sanitize_page'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_page_id]', array(
	'label'             => esc_html__( 'Select Page' , 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_works_section',
	'active_callback'	=> 'tp_philosophy_pro_is_works_content_page_active',
	'type'              => 'dropdown-pages',
) );

// Add works section custom title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_custom_title]',array(
	'sanitize_callback'		=> 'sanitize_text_field',
	'default' 				=> $options['works_custom_title'],
) );
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_custom_title]',array(
	'label'      			=> esc_html__( 'Title', 'tp-philosophy-pro' ),
	'description'			=> esc_html__( 'Enter Title.', 'tp-philosophy-pro' ),
	'section'    			=> 'tp_philosophy_pro_works_section',
    'active_callback'		=> 'tp_philosophy_pro_is_works_content_custom_active',
) );

// Add works section sub title
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_subtitle]',
	array(
		'sanitize_callback'		=> 'sanitize_text_field',
		'default' 				=> $options['works_subtitle'],
	)
);

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_subtitle]',
	array(
		'label'      			=> esc_html__( 'Subtitle', 'tp-philosophy-pro' ),
		'description'			=> esc_html__( 'Enter subtitle.', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_works_section',
	    'active_callback'		=> 'tp_philosophy_pro_is_works_content_demo_inactive',
	)
);

// Add works section quote option
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_custom_quote]',
	array(
		'sanitize_callback'		=> 'tp_philosophy_pro_works_quote_santize_allow_tag',
		'default' 				=> $options['works_custom_quote'],
	)
);
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_custom_quote]',
    array(
		'label'      			=> esc_html__( 'Blog Quotes', 'tp-philosophy-pro' ),
		'description'			=> esc_html__( 'Input blogquotes. Only &lt;blogquotes&gt; and &lt;a&gt; tags are allowed.', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_works_section',
		'type'		 			=> 'textarea',
		'input_attrs' 			=> array(
			'placeholder' 	=> sprintf( '<blockquote>&quot; %1$s &quot;</blockquote>
                  <a href="#" class="worker-name">%2$s</a>', esc_html__( 'The Business Bio-graphy team refined our brand, and designed a web site that we&rsquo;re proud of.', 'tp-philosophy-pro' ), esc_html__( '-Sandeep Regmi, Themepalace.com', 'tp-philosophy-pro' ) ),
		),
        'active_callback'		=> 'tp_philosophy_pro_is_works_content_demo_inactive',
    )
);

// Add works section custom description
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_custom_description]',
	array(
		'sanitize_callback'		=> 'esc_textarea',
		'default' 				=> $options['works_custom_description'],
	)
);
$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_custom_description]',
    array(
		'label'      			=> esc_html__( 'Description', 'tp-philosophy-pro' ),
		'description'			=> esc_html__( 'Input description.', 'tp-philosophy-pro' ),
		'section'    			=> 'tp_philosophy_pro_works_section',
		'type'		 			=> 'textarea',
        'active_callback'		=> 'tp_philosophy_pro_is_works_content_custom_active',
    )
);

// Add learn more text setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_learn_more_text]', array(
	'default'           => $options['works_learn_more_text'],
	'sanitize_callback' => 'sanitize_text_field'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_learn_more_text]', array(
	'label'           	=> esc_html__( 'Learn More Text', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Leave empty to hide button', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_works_section',
	'active_callback' 	=> 'tp_philosophy_pro_is_works_content_demo_inactive',
));

// Add slider link setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_custom_link]', array(
	'default'           => $options['works_custom_link'],
	'sanitize_callback' => 'esc_url_raw'
) );

$wp_customize->add_control( 'tp_philosophy_pro_theme_options[works_custom_link]', array(
	'label'           	=> esc_html__( 'Link', 'tp-philosophy-pro' ),
	'description'		=> esc_html__( 'Input link', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_works_section',
	'type'				=> 'url',
	'active_callback' 	=> 'tp_philosophy_pro_is_works_content_demo_inactive',
));

/**
 * Works options 
 */

// Add graph options setting and control.
$wp_customize->add_setting( 'tp_philosophy_pro_theme_options[works_section_heading]', array(
	'sanitize_callback' => 'esc_textarea'
) );

$wp_customize->add_control( new Tp_Philosophy_Pro_Note_Control( $wp_customize, 'tp_philosophy_pro_theme_options[works_section_heading]', array(
	'label'           	=> esc_html__( 'Work Options', 'tp-philosophy-pro' ),
	'section'         	=> 'tp_philosophy_pro_works_section',
	'type'				=> 'description',
	'active_callback' 	=> 'tp_philosophy_pro_is_works_content_demo_inactive',
) ) );

// Add Category Content Type
$wp_customize->add_setting(  'tp_philosophy_pro_theme_options[works_content_category]', array(
  	'sanitize_callback' => 'tp_philosophy_pro_sanitize_muti_select_categories_list',
) ) ;

$wp_customize->add_control( new Tp_Philosophy_Pro_Multi_Select_Categories_Control ( $wp_customize,'tp_philosophy_pro_theme_options[works_content_category]', array(
	'label'             => esc_html__( 'Select Categories', 'tp-philosophy-pro' ),
	'section'           => 'tp_philosophy_pro_works_section',
	'active_callback'   => 'tp_philosophy_pro_is_works_content_demo_inactive'
) ) );